@@ -9,22 +9,24 @@ function(NewX, X, Y, cova = c('standard', 'M', 'sym')){
   Y <- as.integer(factor(Y))
   L <- max(Y)
 
-  if(is.vector(NewX)) {
-    NewX <- t(NewX)
-  } else {
-    NewX <- as.matrix(NewX)
-  }
-
-
-  if(NCOL(NewX) == 1) {
-    nr <- 1
-    s <- length(NewX)
-  } else {
-    nr <- NROW(NewX)
-    s <- NCOL(NewX)
+  # Stop if lengths of X[,1] and Y do not match
+  if(length(Y) != length(X[,1])) {
+    stop('length(Y) != length(X[,1])')
   }
 
+  NewX <- as.matrix(NewX)
   
+  if(dimension > 1 & NCOL(NewX) == 1) {
+    NewX <- t(NewX)
+  }
+  
+  if(dimension == 1 & NCOL(NewX) > 1) {
+    NewX <- t(NewX)
+  }
+  
+  nr <- NROW(NewX)
+  s <- NCOL(NewX)
+
   # Stop if dimensions of NewX[i,] and X[j,] do not match
   if(s != dimension) {
     stop('dimensions of NewX[i,] and X[j,] do not match!')
@@ -59,7 +61,7 @@ function(NewX, X, Y, cova = c('standard', 'M', 'sym')){
            # Compute mu
            mu <- matrix(0, L, dimension)
            for(b in seq_len(L)) {
-             mu[b, ] = colMeans(X[Y == b, ])
+             mu[b, ] = colMeans(X[Y == b, , drop = FALSE])
            }
            sigma <- sigmaSt(X = X, Y = Y, L = L,
                                       dimension = dimension, n = n, mu = mu)
@@ -76,7 +78,7 @@ function(NewX, X, Y, cova = c('standard', 'M', 'sym')){
            # Compute mu
            mu <- matrix(0, L, dimension)
            for(b in seq_len(L)) {
-             mu[b, ] = colMeans(X[Y == b, ])
+             mu[b, ] = colMeans(X[Y == b, , drop = FALSE])
            }
            tmp <- sigmaSym(X = X, Y = Y, L = L,
                            dimension = dimension, n = n,
